import { newResource, withSpec } from "./resource.js";
import { makeResource } from "./util.js";
export const getFolder = (main) => {
    return main.grafanaDashboardFolder || "General";
};
export const fromMap = (dashboards, folder) => {
    const result = {};
    for (const k in dashboards) {
        result[k] = makeResource("Dashboard", k.replace(/\.json|\.yaml|\.yml$/, ""), dashboards[k], { folder });
    }
    return result;
};
export const fromMixins = (mixins) => {
    const result = {};
    for (const key in mixins) {
        const mixin = mixins[key];
        const folder = mixin.grafanaDashboardFolder || "General";
        for (const k in mixin.grafanaDashboards) {
            result[k] = makeResource("Dashboard", k.replace(/\.json|\.yaml|\.yml$/, ""), mixin.grafanaDashboards[k], { folder });
        }
    }
    return result;
};
export const dashboard = {
    new: (name, dashboardJson) => {
        const resource = newResource("Dashboard", name);
        return withSpec(resource, dashboardJson);
    },
};
export const folder = {
    new: (name, title) => {
        const resource = newResource("DashboardFolder", name);
        return withSpec(resource, { title });
    },
};
export const datasource = {
    new: (name, datasourceJson) => {
        const resource = newResource("Datasource", name);
        return withSpec(resource, datasourceJson);
    },
};
