import { newResource, addMetadata, withSpec } from "./resource.js";
import { makeResource } from "./util.js";
export const getMixinRuleNames = (mixins) => {
    const flatMixins = Object.values(mixins).flat();
    const mixinRules = flatMixins.flatMap((mixin) => mixin.prometheusRules?.groups || []);
    const mixinAlerts = flatMixins.flatMap((mixin) => mixin.prometheusAlerts?.groups || []);
    return [
        ...mixinAlerts.map((group) => group.name),
        ...mixinRules.map((group) => group.name),
    ];
};
export const fromMaps = (rules) => {
    return Object.fromEntries(Object.keys(rules).map((k) => [
        k,
        makeResource("PrometheusRuleGroup", k, { groups: rules }, {}),
    ]));
};
export const fromMapsFiltered = (rules, excludes) => {
    const filterRules = (rules, excludeList) => rules.groups.filter((rule) => !excludeList.includes(rule.name));
    return Object.fromEntries(Object.keys(rules).map((k) => [
        k,
        makeResource("PrometheusRuleGroup", k.replace(/\.json|\.yaml|\.yml$/, ""), { groups: filterRules(rules, excludes) }, {}),
    ]));
};
export const fromMixins = (mixins) => {
    const result = {};
    for (const key in mixins) {
        const mixin = mixins[key];
        if (mixin.prometheusAlerts || mixin.prometheusRules) {
            result[key] = makeResource("PrometheusRuleGroup", key.replace(/\.json|\.yaml|\.yml$/, ""), {
                ...(mixin.prometheusAlerts || {}),
                ...(mixin.prometheusRules || {}),
            }, {});
        }
    }
    return result;
};
export const rule_group = {
    new: (namespace, name, group) => {
        let resource = newResource("PrometheusRuleGroup", name);
        resource = addMetadata(resource, "namespace", namespace);
        resource = withSpec(resource, group);
        return resource;
    },
};
